pub struct Gamma<S, N = F2p2>(/* private fields */)
where
N: Number;Gamma, GammaFn and F2p2 are error prone and incorrectly implemented. See palette::encoding for possible alternatives or implement palette::encoding::FromLinear and palette::encoding::IntoLinear for a custom type.
Gamma encoding.
Gamma encoding or gamma correction is used to transform the intensity
values to either match a non-linear display, like CRT, or to prevent
banding among the darker colors. GammaRgb represents a gamma corrected
RGB color, where the intensities are encoded using the following power-law
expression: V γ (where V is the intensity value an γ is the
encoding gamma).
The gamma value is stored as a simple type that represents an f32
constant.